@@ -8,7 +8,8 @@ class SimpelQrcodesConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     name = "simpel_qrcodes"
     label = "simpel_qrcodes"
-    verbose_name = _("Simpel QRCode")
+    icon = "qrcode-scan"
+    verbose_name = _("QRCodes")
 
     def ready(self):
         post_migrate.connect(init_app, sender=self)
